@@ -300,7 +300,19 @@ def print_node_info(func):
         except:
             print(f'{Color.RED}ERROR:{Color.RESET} The trace log is below.')
             traceback.print_exc()
-            print(f'{Color.RED}ERROR:{Color.RESET} Read this and deal with it. https://github.com/PINTO0309/onnx2tf#parameter-replacement')
+            print(
+                f'{Color.RED}ERROR:{Color.RESET} ' +
+                f'Read this and deal with it. https://github.com/PINTO0309/onnx2tf#parameter-replacement'
+            )
+            print(
+                f'{Color.RED}ERROR:{Color.RESET} ' +
+                f'Alternatively, if the input OP has a dynamic dimension, ' +
+                f'use the -b or -ois option to rewrite it to a static shape and try again.'
+            )
+            print(
+                f'{Color.RED}ERROR:{Color.RESET} ' +
+                f'If the input OP of ONNX before conversion is NHWC, use the -kt option.'
+            )
             sys.exit(1)
     return print_wrapper_func
 
@@ -333,7 +345,11 @@ def inverted_operation_enable_disable(func):
                 and onnx_node_output_shape.count(None) != len(onnx_node_output_shape) \
                 and batch_size is not None:
                 onnx_node_output_shape[0] = batch_size
-            onnx_node_output_shape = [None if s is not None and not isinstance(s, str) and s < 1 else s for s in onnx_node_output_shape]
+            if onnx_node_output_shape is not None:
+                onnx_node_output_shape = [
+                    None if s is not None and not isinstance(s, str) and s < 1 else s \
+                        for s in onnx_node_output_shape
+                ]
             tf_node_output_shape = tf_layers_dict[onnx_node_output.name]['tf_node'].shape
 
             trans_judge = (onnx_node_output_shape != tf_node_output_shape)
